"use strict";
/**
 * @fileoverview Disallow the use of wx.xxSync API
 */
Object.defineProperty(exports, "__esModule", { value: true });
//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------
exports.noWxSyncApi = {
    meta: {
        type: "suggestion",
        docs: {
            description: "Disallow the use of wx.xxSync API",
            category: "WeChat Mini Program Best Practices",
            recommended: false,
            url: "https://github.com/airbnb/eslint-plugin-miniprogram"
        },
        schema: []
    },
    create: function (context) {
        return {
            MemberExpression: function (node) {
                var objectName = node.object.name;
                var propertyName = node.property.name;
                if (objectName === "wx" &&
                    !node.computed &&
                    propertyName &&
                    propertyName.endsWith("Sync")) {
                    context.report({
                        node: node,
                        message: "wx." + propertyName + " may cause performance issue. Use wx." + propertyName.replace(/Sync$/, "") + " instead."
                    });
                }
            }
        };
    }
};
//# sourceMappingURL=no-wx-sync-api.js.map